==> kbarcode-trinity_3.5.13.2.orig.tar.xz: kbarcode-trinity-3.5.13.2/kbarcode/dstextedit.h <==
/***************************************************************************
                         dstextedit.h  -  description
                             -------------------
    begin                : Sam Jun 04 2005
    copyright            : (C) 2005 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _DS_TEXT_EDIT_H_
#define _DS_TEXT_EDIT_H_

#include <tqnamespace.h> 

#include <ktextedit.h>

// Otherwise moc will complain
#define TextEditBase KTextEdit

class DSTextEdit : public TextEditBase {
    Q_OBJECT
  TQ_OBJECT
        
  public:
    DSTextEdit( TQWidget* parent, const char* name = 0 );

    //virtual void moveCursor( CursorAction action, bool select );
  private slots:
    void fixParagraphs();
      
  private:
    /** 
     * returns true if the cursor is currently inside
     * of a token of the form [value].
     */
    //bool cursorIsInToken();
};

#endif // _DS_TEXT_EDIT_H_

==> kbarcode-trinity_14.1.0.orig.tar.xz: kbarcode-trinity-14.1.0/kbarcode/dstextedit.h <==
/***************************************************************************
                         dstextedit.h  -  description
                             -------------------
    begin                : Sam Jun 04 2005
    copyright            : (C) 2005 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef _DS_TEXT_EDIT_H_
#define _DS_TEXT_EDIT_H_

#include <tqnamespace.h>

#include <ktextedit.h>

// Otherwise moc will complain
#define TextEditBase KTextEdit

class DSTextEdit : public KTextEdit {
    Q_OBJECT


  public:
    DSTextEdit( TQWidget* parent, const char* name = 0 );

    //virtual void moveCursor( CursorAction action, bool select );
  private slots:
    void fixParagraphs();

  private:
    /**
     * returns true if the cursor is currently inside
     * of a token of the form [value].
     */
    //bool cursorIsInToken();
};

#endif // _DS_TEXT_EDIT_H_
